﻿-- Author      : Celess
-- Create Date : 11/8/2008 8:59:19 AM

RaidTracker_Export = {

}

function RaidTracker_Export:GenerateRaid( raid )
	local db = KARaidTrackerDB;
	
	if type(raid) ~= "table" then
		KARaidTracker:Print("Bug: Invalid raid table passed to export, please report.");
		return;
	end	
	
	if db.Options.ExportFormat == 1 then
		return self:GenerateMLdkpXML(raid);
	end;
	
	return self:GenerateDkpXML(raid);
end

-- helper functions
function RaidTracker_Export:GetDate( s )
	return (KARaidTrackerDB.Options.ExportFormat == 0) and KARaidTracker:GetDisplayDate(s) or s 
end

function RaidTracker_Export:GenerateMLdkpXML( raid )
    local db = KARaidTrackerDB
    local options = db.Options
    local format = options.ExportFormat

	local race, class, level, sex;
	
	
	local xml ='<?xml version="1.0"?>';
	xml = xml..'<!DOCTYPE ML_Raidtracker PUBLIC "-//MLdkp//DTD ML_Raidtracker V 1.5//EN" "http://www.mldkp.net/dtds/1.0/ML_Raidtracker.dtd">';
	
	xml = xml.."<raidinfo>";
	xml = xml.."<version>1.5</version>";
	
	xml = xml.."<start>"..self:GetDate(raid.Key).."</start>";
	xml = xml.."<end>"..self:GetDate(raid.End).."</end>";

	if raid.zone then
		xml = xml.."<zone>"..raid.zone.."</zone>";
	end
	if raid.instanceid then
		xml = xml.."<instanceid>"..raid.instanceid.."</instanceid>";
	end
	xml = xml.."<exporter>"..UnitName("Player").."</exporter>";
	
	if raid.PlayerInfos then
		xml = xml.."<playerinfos>";
		for k, v in pairs(raid.PlayerInfos) do
			xml = xml.."<player>";
			xml = xml.."<name>"..k.."</name>";
			for k2, v2 in pairs(raid.PlayerInfos[k]) do
				if k2 == "note" then
					xml = xml.."<"..k2.."><![CDATA["..v2.."]]></"..k2..">";
				elseif k2 == "class" then
					xml = xml.."<"..k2..">"..KARaidTracker._lookup.ClassToId[v2].."</"..k2..">";
				elseif k2 == "race" then
					xml = xml.."<"..k2..">"..KARaidTracker._lookup.RaceToId[v2].."</"..k2..">";
				elseif k2 == "level" then
					if db.Options.LevelMax < v2 then
						xml = xml.."<"..k2..">"..v2.."</"..k2..">";
					end;
				else
					xml = xml.."<"..k2..">"..v2.."</"..k2..">";
				end
			end
			xml = xml.."</player>";
		end
		xml = xml.."</playerinfos>";
	end
	if raid.Events then
		local bosskillsindex = 1;
		xml = xml.."<bosskills>";
		for k, v in pairs(raid.Events) do
			xml = xml.."<bosskill>";
			xml = xml.."<name>"..v.boss.."</name>";
			xml = xml.."<time>"..self:GetDate(v.time).."</time>";
			xml = xml.."</bosskill>";
		end
		xml = xml.."</bosskills>";
	end
	if raid.wipes then
		xml = xml.."<wipes>";
		for k, v in pairs(raid.wipes) do
			xml = xml.."<wipe><time>"..v.."</time></wipe>";
		end
		xml = xml.."</wipes>";
	end
	if raid.bossnext then
		xml = xml.."<nextboss>"..raid.bossnext.."</nextboss>";
	end

	if raid.note then 
		xml = xml.."<note><![CDATA["..raid.note.."]]></note>"; 
	end

	xml = xml.."<joins>";
	for k, v in pairs(raid.Join) do
		xml = xml.."<join>";
		xml = xml.."<player>"..v.player.."</player>";
		xml = xml.."<time>"..self:GetDate(v.time).."</time>";
		xml = xml.."</join>";
	end
	xml = xml.."</joins>";
	xml = xml.."<leaves>";
	for k, v in pairs(raid.Leave) do
		xml = xml.."<leave>";
		xml = xml.."<player>"..v.player.."</player>";
		xml = xml.."<time>"..self:GetDate(v.time).."</time>";
		xml = xml.."</leave>";
	end
	xml = xml.."</leaves>";
	xml = xml.."<loots>";
	
	for k, v in pairs(raid.Loot) do
		xml = xml.."<loot>";
		xml = xml.."<itemname>"..v.item.name.."</itemname>";
		xml = xml.."<itemid>"..v.item.id.."</itemid>";
		xml = xml.."<count>"..((v.item.count) and v.item.count or 1).."</count>";
		xml = xml.."<player>"..v.player.."</player>";
		if v.costs then
			xml = xml.."<costs>"..v.costs.."</costs>";
		end
		xml = xml.."<time>"..self:GetDate(v.time).."</time>";
		if v.zone then 
			xml = xml.."<zone>"..v.zone.."</zone>";
		end
		if v.boss then 
			xml = xml.."<boss>"..v.boss.."</boss>";
		end
		if v.note then 
			xml = xml.."<note><![CDATA["..v.note.."]]></note>";
		end
		xml = xml.."</loot>";
	end
	xml = xml.."</loots>";
	xml = xml.."</raidinfo>";
	
	return xml;
end


function RaidTracker_Export:GenerateDkpXML( raid )
    local db = KARaidTrackerDB
    local options = db.Options
    local format = options.ExportFormat
	
	local xml = "<RaidInfo>"
	if format == 0 then
		local xml = xml.."<Version>1.4</Version>";
	end
	
	if format == 0 then
		xml = xml.."<key>"..self:GetDate(raid.Key).."</key>";
	end
	xml = xml.."<start>"..self:GetDate(raid.Key).."</start>";
	
	if raid.End then
		xml = xml.."<end>"..self:GetDate(raid.End).."</end>";
	end
	if raid.zone then
		xml = xml.."<zone>"..raid.zone.."</zone>";
	end
	if raid.PlayerInfos then
		xml = xml.."<PlayerInfos>";
		local idx = 1;
		for k, v in pairs(raid.PlayerInfos) do
			xml = xml.."<key"..idx..">";
			xml = xml.."<name>"..k.."</name>";
			for k2, v2 in pairs(raid.PlayerInfos[k]) do
				if k2 == "note" then
					xml = xml.."<"..k2.."><![CDATA["..v2.."] ]></"..k2..">";
				
				else
					xml = xml.."<"..k2..">"..v2.."</"..k2..">";
				end
			end
			xml = xml.."</key"..idx..">";
			idx = idx + 1;
		end
		xml = xml.."</PlayerInfos>";
	end
	if raid.Events then
		local bosskillsindex = 1;
		xml = xml.."<BossKills>";
		for k, v in pairs(raid.Events) do
			xml = xml.."<key"..bosskillsindex..">";
			xml = xml.."<name>"..v.boss.."</name>";
			xml = xml.."<time>"..self:GetDate(v.time).."</time>";
			if format ~= 1 then
				xml = xml.."<time>"..v.time.."</time>";
				if  raid.Events[k].attendees then
					xml = xml.."<attendees>";
					for k2, v2 in pairs(raid.Events[k].attendees) do
						xml = xml.."<key"..k2..">";
						xml = xml.."<name>"..v2.."</name>";
						xml = xml.."</key"..k2..">";
					end
					xml = xml.."</attendees>";
				end
			end
			xml = xml.."</key"..bosskillsindex..">";
			bosskillsindex = bosskillsindex + 1;
		end
		xml = xml.."</BossKills>";
	end
	-- new exports
	if raid.wipes then
		xml = xml.."<Wipes>";
		for k, v in pairs(raid.wipes) do
			xml = xml.."<Wipe>"..v.."</Wipe>";
		end
		xml = xml.."</Wipes>";
	end
	if raid.bossnext then
		xml = xml.."<NextBoss>"..raid.bossnext.."</NextBoss>";
	end
	--	
	if format == 0 then
		local sNote = "<note><![CDATA[";
		if raid.note then sNote = sNote..raid.note; end
		if raid.zone then sNote = sNote.." - Zone: "..raid.zone; end
		sNote = sNote.."]]></note>";
		xml = xml..sNote;
	else
		if raid.note then xml = xml.."<note><![CDATA["..raid.note.."]]></note>"; end
	end
	xml = xml.."<Join>";
	for k, v in pairs(raid.Join) do
		xml = xml.."<key"..k..">";
		xml = xml.."<player>"..v.player.."</player>";
		if format == 0 then
			if v.race then
				race = v.race; 
			elseif raid.PlayerInfos and raid.PlayerInfos[v.player] and raid.PlayerInfos[v.player].race then
				race = raid.PlayerInfos[v.player].race; 
			else
				race = nil;
			end
			if v.class then
				class = v.class; 
			elseif raid.PlayerInfos and raid.PlayerInfos[v.player] and raid.PlayerInfos[v.player].class then
				class = raid.PlayerInfos[v.player].class; 
			else
				class = nil;
			end
			if v.sex then
				sex = v.sex; 
			elseif raid.PlayerInfos and raid.PlayerInfos[v.player] and raid.PlayerInfos[v.player].sex then
				sex = raid.PlayerInfos[v.player].sex; 
			else
				sex = nil;
			end
			if v.level then
				level = v.level; 
			elseif raid.PlayerInfos and raid.PlayerInfos[v.player] and raid.PlayerInfos[v.player].level then
				level = raid.PlayerInfos[v.player].level; 
			else
				level = nil;
			end
			if race then xml = xml.."<race>"..race.."</race>"; end
			if class then xml = xml.."<class>"..class.."</class>"; end
			if sex then xml = xml.."<sex>"..sex.."</sex>"; end
			if level then xml = xml.."<level>"..level.."</level>"; end
		end
		if format == 0 and raid.PlayerInfos[v.player] and raid.PlayerInfos[v.player].note then xml = xml.."<note>"..raid.PlayerInfos[v.player].note.."</note>"; end
		xml = xml.."<time>"..self:GetDate(v.time).."</time>";
		xml = xml.."</key"..k..">";
	end
	xml = xml.."</Join>";
	xml = xml.."<Leave>";
	for k, v in pairs(raid.Leave) do
		xml = xml.."<key"..k..">";
		xml = xml.."<player>"..v.player.."</player>";
		xml = xml.."<time>"..self:GetDate(v.time).."</time>";
		xml = xml.."</key"..k..">";
	end
	xml = xml.."</Leave>";
	xml = xml.."<Loot>";
	for k, v in pairs(raid.Loot) do
		xml = xml.."<key"..k..">";
		xml = xml.."<ItemName>"..v.item.name.."</ItemName>";
		xml = xml.."<ItemID>"..v.item.id.."</ItemID>";
		if v.item.icon then xml = xml.."<Icon>"..v.item.icon.."</Icon>"; end
		if v.item.class then xml = xml.."<Class>"..v.item.class.."</Class>"; end
		if v.item.subclass then xml = xml.."<SubClass>"..v.item.subclass.."</SubClass>"; end
		xml = xml.."<Color>"..v.item.c.."</Color>";
		xml = xml.."<Count>"..((v.item.count) and v.item.count or 1).."</Count>";
		xml = xml.."<Player>"..v.player.."</Player>";
		if v.costs then
			xml = xml.."<Costs>"..v.costs.."</Costs>";
		end
		xml = xml.."<Time>"..self:GetDate(v.time).."</Time>";
		if v.zone then xml = xml.."<Zone>"..v.zone.."</Zone>"; end
		if v.boss then xml = xml.."<Boss>"..v.boss.."</Boss>"; end
		if format == 0 then
			local sNote = "<Note><![CDATA[";
			if v.note then sNote = sNote..v.note; end
			if v.zone then sNote = sNote.." - Zone: "..v.zone; end
			if v.boss then sNote = sNote.." - Boss: "..v.boss; end
			if v.costs then sNote = sNote.." - "..v.costs.." DKP"; end
			sNote = sNote.."]]></Note>";
			xml = xml..sNote;
		else
			if v.note then xml = xml.."<Note><![CDATA["..v.note.."]]></Note>"; end
		end
		xml = xml.."</key"..k..">";
	end
	xml = xml.."</Loot>";
	xml = xml.."</RaidInfo>";
	
	return xml;
end

